==> docfbe_2_2_31_55.zip: docfbe_2_2_31_55/source/TCFbERankCorrelation.h <==
/*
    TCFbERankCorrelation.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbERankCorrelationH
#define TCFbERankCorrelationH
//---------------------------------------------------------------------------
#include "TCFbESimilarityComputationAlgorithm.h"

class TCFbEDataSet;
#include "TCFbEDataSet.h"

#include "TCFbECell.h"
#include "TCFbEToolkit.h"
#include <math.h>
//---------------------------------------------------------------------------
class TCFbERankCorrelation : public TCFbESimilarityComputationAlgorithm
{
public:
    virtual __fastcall TCFbERankCorrelation(void);    // RXgN^
    __fastcall ~TCFbERankCorrelation();    // fXgN^

    virtual double __fastcall ComputeSimilarity(int TargetRowIndex, int ComparedRowIndex);    // TargetRowIndex  AnotherRowIndex ̗ގxvZ

protected:
    virtual void __fastcall DoRanking(TList* RankedList);    // LO쐬

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_2_34_61.zip: docfbe_2_2_34_61/source/TCFbERankCorrelation.h <==
/*
    TCFbERankCorrelation.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbERankCorrelationH
#define TCFbERankCorrelationH
//---------------------------------------------------------------------------
#include "TCFbESimilarityComputationAlgorithm.h"

class TCFbEDataSet;
#include "TCFbEDataSet.h"

#include "TCFbECell.h"
#include "TCFbEToolkit.h"
#include <math.h>
//---------------------------------------------------------------------------
class TCFbERankCorrelation : public TCFbESimilarityComputationAlgorithm
{
public:
    virtual __fastcall TCFbERankCorrelation(void);    // RXgN^
    __fastcall ~TCFbERankCorrelation();    // fXgN^

    virtual double __fastcall ComputeSimilarity(TCFbETable* SimilarityComputationTable, int TargetRowIndex, int ComparedRowIndex);    // TargetRowIndex  AnotherRowIndex ̗ގxvZ

protected:
    virtual void __fastcall DoRanking(TList* RankedList);    // LO쐬

private:

};
//---------------------------------------------------------------------------
#endif
